pub fn gen_mempool_reconfig_subscription() -> (ReconfigSubscription, Receiver<(), OnChainConfigPayload>)Expand description
The mempool reconfig subscription no longer subscribes to any specific
on-chain configs. Previously it subscribed to DiemVersion and VMConfig,
but those Diem config types were dead code in Conflux PoS (commented out
of ON_CHAIN_CONFIG_REGISTRY and never populated) so removing them has
no behavioral effect.